@@ -8,10 +8,10 @@
 #' @param to_date end date for search, e.g. `'2022-04-03'`. Defaults to most recent.
 #' @param limit number of records to return. Default is 20. Will be truncated to between 1 and 250.
 #' @param offset number of records to skip. Default is 0. Must be non-negative.
-#' @param clean Default is TRUE. Should output be returned as a `tibble` (`TRUE`) or requested `format`.
+#' @param clean Default is `TRUE`. Should output be returned as a `tibble` (`TRUE`) or requested `format`.
 #' @param format Output format for `clean = FALSE`. One of `xml` or `json`.
 #'
-#' @return `tibble` or HTTP response if `clean = FALSE`.
+#' @return a `tibble::tibble` or HTTP response if `clean = FALSE`.
 #' @export
 #'
 #' @examplesIf congress::has_congress_key()
@@ -31,6 +31,10 @@ cong_amendment <- function(congress = NULL, type = NULL, number = NULL, item = N
                            format = 'json', clean = TRUE) {
   sort <- NULL
   check_format(format)
+  if (clean) {
+    format <- 'json'
+  }
+
   from_date <- check_date(from_date)
   to_date <- check_date(to_date)
   if (is.null(from_date) & !is.null(to_date) || !is.null(from_date) & is.null(to_date)) {
@@ -53,17 +57,17 @@ cong_amendment <- function(congress = NULL, type = NULL, number = NULL, item = N
       'offset' = max(offset, 0)
     ) |>
     httr2::req_headers(
-      "accept" = glue::glue("application/{format}")
+      'accept' = glue::glue('application/{format}')
     )
   resp <- req |>
     httr2::req_perform()
 
   formatter <- switch(format,
-                      'json' = httr2::resp_body_json,
-                      'xml' = httr2::resp_body_xml
+    'json' = httr2::resp_body_json,
+    'xml' = httr2::resp_body_xml
   )
 
-  out <- resp <- resp |>
+  out <- resp |>
     formatter()
 
   if (clean) {
@@ -78,15 +82,23 @@ cong_amendment <- function(congress = NULL, type = NULL, number = NULL, item = N
           purrr::pluck('amendment') |>
           tibble::enframe() |>
           tidyr::pivot_wider() |>
-          tidyr::unnest_wider(col = where(~purrr::pluck_depth(.x) < 4), simplify = TRUE, names_sep = '_') |>
+          tidyr::unnest_wider(col = where(~ purrr::pluck_depth(.x) < 4), simplify = TRUE, names_sep = '_') |>
           dplyr::rename_with(.fn = function(x) stringr::str_sub(x, end = -3), .cols = dplyr::ends_with('_1')) |>
           clean_names() #|>
-        #dplyr::mutate(across(where(is.list), function(x) if (max(lengths(x)) == 1 ) dplyr::bind_rows(x) else dplyr::bind_rows(purrr::set_names(x, seq_along(x)))))
+        # dplyr::mutate(across(where(is.list), function(x) if (max(lengths(x)) == 1 ) dplyr::bind_rows(x) else dplyr::bind_rows(purrr::set_names(x, seq_along(x)))))
       } else {
-        out <- out |>
-          purrr::pluck(item) |>
-          list_hoist() |>
-          clean_names()
+        if (item == 'text') {
+          out <- out |>
+            purrr::pluck('textVersions') |>
+            lapply(widen) |>
+            purrr::list_rbind() |>
+            clean_names()
+        } else {
+          out <- out |>
+            purrr::pluck(item) |>
+            list_hoist() |>
+            clean_names()
+        }
       }
     }
     out <- out |>
@@ -96,7 +108,7 @@ cong_amendment <- function(congress = NULL, type = NULL, number = NULL, item = N
   out
 }
 
-amendment_items <- c('actions', 'amendments', 'cosponsors')
+amendment_items <- c('actions', 'amendments', 'cosponsors', 'text')
 amendment_types <- c('hamdt', 'samdt', 'suamdt')
 
 amendment_endpoint <- function(congress, type, number, item) {
