@@ -4,7 +4,7 @@
 #' @param type Type of bill. Can be `'hr'`, `'s'`, `'hjres'`, `'sjres'`, `'hconres'`, `'sconres'`, `'hres'`, or `'sres'`.
 #' @param number Bill assigned number. Numeric.
 #' @param item Information to request. Can be `'actions'`, `'amendments'`, `'committees'`, `'cosponsors'`,
-#' `'relatedbills'`, `'subjects'`, `'text'`, or `'titles'`
+#' `'relatedbills'`, `'subjects'`, '`summaries`', `'text'`, or `'titles'`
 #' @param from_date start date for search, e.g. `'2022-04-01'`. Defaults to most recent.
 #' @param to_date end date for search, e.g. `'2022-04-03'`. Defaults to most recent.
 #' @param limit number of records to return. Default is 20. Will be truncated to between 1 and 250.
@@ -12,7 +12,7 @@
 #' @param clean Default is TRUE. Should output be returned as a `tibble` (`TRUE`) or requested `format`.
 #' @param format Output format for `clean = FALSE`. One of `xml` or `json`.
 #'
-#' @return `tibble` or HTTP response if `clean = FALSE`
+#' @return a `tibble::tibble` or HTTP response if `clean = FALSE`
 #' @export
 #'
 #' @examplesIf congress::has_congress_key()
@@ -32,6 +32,10 @@ cong_bill <- function(congress = NULL, type = NULL, number = NULL, item = NULL,
                       format = 'json', clean = TRUE) {
   sort <- NULL
   check_format(format)
+  if (clean) {
+    format <- 'json'
+  }
+
   from_date <- check_date(from_date)
   to_date <- check_date(to_date)
   if (is.null(from_date) & !is.null(to_date) || !is.null(from_date) & is.null(to_date)) {
@@ -50,17 +54,17 @@ cong_bill <- function(congress = NULL, type = NULL, number = NULL, item = NULL,
       'offset' = max(offset, 0)
     ) |>
     httr2::req_headers(
-      "accept" = glue::glue("application/{format}")
+      'accept' = glue::glue('application/{format}')
     )
   resp <- req |>
     httr2::req_perform()
 
   formatter <- switch(format,
-                      'json' = httr2::resp_body_json,
-                      'xml' = httr2::resp_body_xml
+    'json' = httr2::resp_body_json,
+    'xml' = httr2::resp_body_xml
   )
 
-  out <- resp <- resp |>
+  out <- resp |>
     formatter()
 
   if (clean) {
@@ -75,34 +79,28 @@ cong_bill <- function(congress = NULL, type = NULL, number = NULL, item = NULL,
           purrr::pluck('bill') |>
           tibble::enframe() |>
           tidyr::pivot_wider() |>
-          tidyr::unnest_wider(col = where(~purrr::pluck_depth(.x) < 4), simplify = TRUE, names_sep = '_') |>
+          tidyr::unnest_wider(col = where(~ purrr::pluck_depth(.x) < 4), simplify = TRUE, names_sep = '_') |>
           dplyr::rename_with(.fn = function(x) stringr::str_sub(x, end = -3), .cols = dplyr::ends_with('_1')) |>
           clean_names()
       } else {
-        if (item == 'text')  {
-          item <- 'textVersions'
+        if (item == 'text') {
           out <- out |>
-            purrr::pluck(item)
-
-          out <- lapply(out, function(x) {
-            x[[2]] <- x$formats |>
-              dplyr::bind_rows() |>
-              tidyr::pivot_wider(names_from = 'type', values_from = 'url') |>
-              dplyr::rename_with(.fn = function(x) paste0('url_', str_colname(x)))
-            x
-          })
-
+            purrr::pluck('textVersions') |>
+            lapply(widen) |>
+            purrr::list_rbind() |>
+            clean_names()
+        } else if (item == 'committees') {
           out <- out |>
-            dplyr::bind_rows() |>
-            tidyr::unnest_wider(col = 'formats') |>
+            purrr::pluck(item) |>
+            lapply(widen) |>
+            purrr::list_rbind() |>
             clean_names()
         } else {
           out <- out |>
             purrr::pluck(item) |>
             list_hoist() |>
             clean_names()
-       }
-
+        }
       }
     }
     out <- out |>
@@ -112,7 +110,10 @@ cong_bill <- function(congress = NULL, type = NULL, number = NULL, item = NULL,
   out
 }
 
-bill_items <- c('actions', 'amendments', 'committees', 'cosponsors', 'relatedbills', 'subjects', 'text', 'titles')
+bill_items <- c(
+  'actions', 'amendments', 'committees', 'cosponsors', 'relatedbills',
+  'subjects', 'summaries', 'text', 'titles'
+)
 bill_types <- c('hr', 's', 'hjres', 'sjres', 'hconres', 'sconres', 'hres', 'sres')
 
 bill_endpoint <- function(congress, type, number, item) {
