@@ -9,10 +9,10 @@
 #' @param to_date end date for search, e.g. `'2022-04-03'`. Defaults to most recent.
 #' @param limit number of records to return. Default is 20. Will be truncated to between 1 and 250.
 #' @param offset number of records to skip. Default is 0. Must be non-negative.
-#' @param clean Default is TRUE. Should output be returned as a `tibble` (`TRUE`) or requested `format`.
+#' @param clean Default is `TRUE`. Should output be returned as a `tibble` (`TRUE`) or requested `format`.
 #' @param format Output format for `clean = FALSE`. One of `xml` or `json`.
 #'
-#' @return `tibble` or HTTP response if `clean = FALSE`
+#' @return a `tibble::tibble` or HTTP response if `clean = FALSE`
 #' @export
 #'
 #' @examplesIf congress::has_congress_key()
@@ -37,11 +37,15 @@
 #' cong_committee(chamber = 'senate', committee = 'slpo00', item = 'senate-communication')
 #'
 cong_committee <- function(congress = NULL, chamber = NULL, committee = NULL, item = NULL,
-                      from_date = NULL, to_date = NULL,
-                      limit = 20, offset = 0,
-                      format = 'json', clean = TRUE) {
+                           from_date = NULL, to_date = NULL,
+                           limit = 20, offset = 0,
+                           format = 'json', clean = TRUE) {
   sort <- NULL
   check_format(format)
+  if (clean) {
+    format <- 'json'
+  }
+
   from_date <- check_date(from_date)
   to_date <- check_date(to_date)
   if (is.null(from_date) & !is.null(to_date) || !is.null(from_date) & is.null(to_date)) {
@@ -60,35 +64,31 @@ cong_committee <- function(congress = NULL, chamber = NULL, committee = NULL, it
       'offset' = max(offset, 0)
     ) |>
     httr2::req_headers(
-      "accept" = glue::glue("application/{format}")
+      'accept' = glue::glue('application/{format}')
     )
   resp <- req |>
     httr2::req_perform()
 
   formatter <- switch(format,
-                      'json' = httr2::resp_body_json,
-                      'xml' = httr2::resp_body_xml
+    'json' = httr2::resp_body_json,
+    'xml' = httr2::resp_body_xml
   )
 
-  out <- resp <- resp |>
+  out <- resp |>
     formatter()
 
   if (clean) {
     if (is.null(committee)) {
       out <- out |>
-        purrr::pluck('committees')
-      out <- out |>
-        tibble::tibble(x = out) |>
-        tidyr::unnest_wider('x') |>
+        purrr::pluck('committees') |>
+        lapply(widen) |>
+        purrr::list_rbind() |>
         clean_names()
     } else {
       if (is.null(item)) {
         out <- out |>
           purrr::pluck('committee') |>
-          tibble::enframe() |>
-          tidyr::pivot_wider() |>
-          tidyr::unnest_wider(col = where(~purrr::pluck_depth(.x) < 4), simplify = TRUE, names_sep = '_') |>
-          dplyr::rename_with(.fn = function(x) stringr::str_sub(x, end = -3), .cols = dplyr::ends_with('_1')) |>
+          widen() |>
           clean_names()
       } else {
         if (item == 'reports') {
@@ -111,17 +111,19 @@ cong_committee <- function(congress = NULL, chamber = NULL, committee = NULL, it
             purrr::pluck('senateCommunications') |>
             list_hoist() |>
             clean_names()
-        } else{
-          out <- out |>
+        } else {
+          singles <- out |>
             purrr::pluck('committee-bills') |>
-            tibble::enframe() |>
-            tidyr::pivot_wider() |>
-            tidyr::unnest_wider(col = where(~purrr::pluck_depth(.x) < 4), simplify = TRUE, names_sep = '_') |>
-            tidyr::unnest_longer(dplyr::any_of('bills')) |>
-            tidyr::unnest_wider(dplyr::any_of('bills')) |>
+            purrr::discard_at('bills') |>
+            widen() |>
+            dplyr::rename_with(.fn = function(x) paste0('committee_bill_', x))
+          out <- out |>
+            purrr::pluck('committee-bills', 'bills') |>
+            lapply(widen) |>
+            purrr::list_rbind() |>
             clean_names()
+          out <- dplyr::bind_cols(singles, out)
         }
-
       }
     }
     out <- out |>
@@ -132,7 +134,10 @@ cong_committee <- function(congress = NULL, chamber = NULL, committee = NULL, it
 }
 
 committee_chambers <- c('house', 'senate', 'joint')
-committee_items <- c('bills', 'reports', 'nominations')
+committee_items <- c(
+  'bills', 'reports', 'nominations', 'house-communication',
+  'senate-communication'
+)
 
 committee_endpoint <- function(congress, committee, chamber, item) {
   out <- 'committee'
