@@ -1,6 +1,7 @@
 #' Request Congress Information
 #'
-#' @param congress Congress number to search for. 81 or later are supported.
+#' @param congress Congress number to search for. 81 or later are supported. Also
+#' accepts the string `'current'` to get the current Congress.
 #' @param from_date start date for search, e.g. `'2022-04-01'`. Defaults to most recent.
 #' @param to_date end date for search, e.g. `'2022-04-03'`. Defaults to most recent.
 #' @param limit number of records to return. Default is 20. Will be truncated to between 1 and 250.
@@ -8,7 +9,7 @@
 #' @param format Output format for `clean = FALSE`. One of `xml` or `json`.
 #' @param clean Default is TRUE. Should output be returned as a `tibble` (`TRUE`) or requested `format`.
 #'
-#' @return `tibble` or HTTP response if `clean = FALSE`
+#' @return a `tibble::tibble` or HTTP response if `clean = FALSE`
 #' @export
 #'
 #' @examplesIf congress::has_congress_key()
@@ -19,6 +20,7 @@
 #'
 #' cong_congress(congress = 116)
 #'
+#' cong_congress(congress = 'current')
 #'
 cong_congress <- function(congress = NULL,
                           from_date = NULL, to_date = NULL,
@@ -26,6 +28,10 @@ cong_congress <- function(congress = NULL,
                           format = 'json', clean = TRUE) {
   sort <- NULL
   check_format(format)
+  if (clean) {
+    format <- 'json'
+  }
+
   from_date <- check_date(from_date)
   to_date <- check_date(to_date)
   if (is.null(from_date) & !is.null(to_date) || !is.null(from_date) & is.null(to_date)) {
@@ -44,18 +50,18 @@ cong_congress <- function(congress = NULL,
       'offset' = max(offset, 0)
     ) |>
     httr2::req_headers(
-      "accept" = glue::glue("application/{format}")
+      'accept' = glue::glue('application/{format}')
     )
 
   resp <- req |>
     httr2::req_perform()
 
   formatter <- switch(format,
-                      'json' = httr2::resp_body_json,
-                      'xml' = httr2::resp_body_xml
+    'json' = httr2::resp_body_json,
+    'xml' = httr2::resp_body_xml
   )
 
-  out <- resp <- resp |>
+  out <- resp |>
     formatter()
 
   if (clean) {
@@ -68,10 +74,7 @@ cong_congress <- function(congress = NULL,
     } else {
       out <- out |>
         purrr::pluck('congress') |>
-        tibble::enframe() |>
-        tidyr::pivot_wider() |>
-        tidyr::unnest_wider(col = where(~purrr::pluck_depth(.x) < 4), simplify = TRUE, names_sep = '_') |>
-        dplyr::rename_with(.fn = function(x) stringr::str_sub(x, end = -3), .cols = dplyr::ends_with('_1')) |>
+        widen() |>
         clean_names()
     }
     out <- out |>
