@@ -8,7 +8,7 @@
 #' @param clean Default is TRUE. Should output be returned as a `tibble` (`TRUE`) or requested `format`.
 #' @param format Output format for `clean = FALSE`. One of `xml` or `json`.
 #'
-#' @return `tibble` or HTTP response if `clean = FALSE`
+#' @return a `tibble::tibble` or HTTP response if `clean = FALSE`
 #' @export
 #'
 #' @examplesIf congress::has_congress_key()
@@ -24,6 +24,9 @@ cong_record <- function(year = NULL, month = NULL, day = NULL,
                         format = 'json', clean = TRUE) {
   sort <- NULL
   check_format(format)
+  if (clean) {
+    format <- 'json'
+  }
 
   endpt <- record_endpoint()
   req <- httr2::request(base_url = api_url()) |>
@@ -38,17 +41,17 @@ cong_record <- function(year = NULL, month = NULL, day = NULL,
       'offset' = max(offset, 0)
     ) |>
     httr2::req_headers(
-      "accept" = glue::glue("application/{format}")
+      'accept' = glue::glue('application/{format}')
     )
   resp <- req |>
     httr2::req_perform()
 
   formatter <- switch(format,
-                      'json' = httr2::resp_body_json,
-                      'xml' = httr2::resp_body_xml
+    'json' = httr2::resp_body_json,
+    'xml' = httr2::resp_body_xml
   )
 
-  out <- resp <- resp |>
+  out <- resp |>
     formatter()
 
   if (clean) {
@@ -56,10 +59,14 @@ cong_record <- function(year = NULL, month = NULL, day = NULL,
       purrr::pluck('Results') |>
       tibble::enframe() |>
       tidyr::pivot_wider() |>
-      tidyr::unnest_wider(col = where(~purrr::pluck_depth(.x) < 4), simplify = TRUE, names_sep = '_') |>
+      tidyr::unnest_wider(col = where(~ purrr::pluck_depth(.x) < 4), simplify = TRUE, names_sep = '_') |>
       dplyr::rename_with(.fn = function(x) stringr::str_sub(x, end = -3), .cols = dplyr::ends_with('_1')) |>
       clean_names()
 
+    out$issues <- lapply(out$issues, function(z) {
+      dplyr::bind_rows(z)
+    })
+
     out <- out |>
       add_resp_info(resp) |>
       cast_date_columns()
