@@ -9,7 +9,7 @@
 #' @param format Output format for `clean = FALSE`. One of `xml` or `json`.
 #' @param clean Default is TRUE. Should output be returned as a `tibble` (`TRUE`) or requested `format`.
 #'
-#' @return `tibble` or HTTP response if `clean = FALSE`
+#' @return a `tibble::tibble` or HTTP response if `clean = FALSE`
 #' @export
 #'
 #' @examplesIf congress::has_congress_key()
@@ -28,6 +28,10 @@ cong_summaries <- function(congress = NULL, type = NULL,
                            format = 'json', clean = TRUE) {
   sort <- NULL
   check_format(format)
+  if (clean) {
+    format <- 'json'
+  }
+
   from_date <- check_date(from_date)
   to_date <- check_date(to_date)
   if (is.null(from_date) & !is.null(to_date) || !is.null(from_date) & is.null(to_date)) {
@@ -46,18 +50,18 @@ cong_summaries <- function(congress = NULL, type = NULL,
       'offset' = max(offset, 0)
     ) |>
     httr2::req_headers(
-      "accept" = glue::glue("application/{format}")
+      'accept' = glue::glue('application/{format}')
     )
 
   resp <- req |>
     httr2::req_perform()
 
   formatter <- switch(format,
-                      'json' = httr2::resp_body_json,
-                      'xml' = httr2::resp_body_xml
+    'json' = httr2::resp_body_json,
+    'xml' = httr2::resp_body_xml
   )
 
-  out <- resp <- resp |>
+  out <- resp |>
     formatter()
 
   if (clean) {
