@@ -1,12 +1,12 @@
-test_that("has_congress_key works", {
+test_that('has_congress_key works', {
   expect_true(is.logical(has_congress_key()))
 })
 
-test_that("get_congress_key works", {
+test_that('get_congress_key works', {
   expect_true(is.character(get_congress_key()))
 })
 
-test_that("set_congress_key works", {
+test_that('set_congress_key works', {
   testthat::skip_if_not_installed('withr')
   withr::with_envvar(
     c('CONGRESS_KEY' = NA_character_),
